@@ -2,19 +2,20 @@
 # -*- coding: utf-8 -*-
 
 # insert the package for universal imports.
-import os, sys, fil3s
-sys.path.insert(1, fil3s.gfp.base(path=__file__, back=2))
+import os, sys
+from dev0s import *
+sys.path.insert(1, gfp.base(path=__file__, back=2))
 
 # imports.
-import syst3m
 from syst3m.classes.config import *
+import syst3m
 
 # the cli object class.
-class CLI(cl1.CLI):
+class CLI_(CLI.CLI):
 	def __init__(self):
 		
 		# defaults.
-		cl1.CLI.__init__(self,
+		CLI.CLI.__init__(self,
 			modes={
 				"--user myuser":"Configure a system user (linux).",
 				"    --check":"Check the existance of the specified user.",
@@ -46,15 +47,15 @@ class CLI(cl1.CLI):
 	def start(self):
 
 		# check arguments.
-		self.arguments.check(json=syst3m.defaults.options.json)
+		self.arguments.check(json=Defaults.options.json)
 
 		# help.
 		if self.arguments.present(['-h', '--help']):
-			self.docs(success=True, json=syst3m.defaults.options.json)
+			self.docs(success=True, json=Defaults.options.json)
 
 		# version.
 		elif self.arguments.present(['--version']):
-			self.stop(message=f"{ALIAS} version:"+Files.load(f"{SOURCE_PATH}/.version.py").replace("\n",""), json=syst3m.defaults.options.json)
+			self.stop(message=f"{ALIAS} version:"+Files.load(f"{SOURCE_PATH}/.version.py").replace("\n",""), json=Defaults.options.json)
 
 		# config.
 		#elif self.arguments.present('--config'):
@@ -65,7 +66,7 @@ class CLI(cl1.CLI):
 
 		# user.
 		elif self.arguments.present(['--user']):
-			syst3m.defaults.operating_system(supported=["linux"])
+			Defaults.operating_system(supported=["linux"])
 
 			# initialize a user object.
 			user = syst3m.User(self.arguments.get("--user"))
@@ -73,36 +74,36 @@ class CLI(cl1.CLI):
 			# check if the user exists.
 			if self.arguments.present(['--check']):
 				response = user.check()
-				r3sponse.log(response)
+				Response.log(response)
 				if response.success: print("User existance:",response["exists"])
 
 			# create a user.
 			elif self.arguments.present(['--create']):
 				response = user.create()
-				r3sponse.log(response)
+				Response.log(response)
 
 			# delete a user.
 			elif self.arguments.present(['--delete']):
 				response = user.delete()
-				r3sponse.log(response)
+				Response.log(response)
 
 			# set a users password.
 			elif self.arguments.present(['--password']):
 				password = self.get_password(retrieve=True, message=f"Enter a new password of user [{user.username}]:")
 				response = user.set_password(password=password)
-				r3sponse.log(response)
+				Response.log(response)
 
 			# add the user to groups.
 			elif self.arguments.present(['--add-groups']):
 				groups = self.arguments.get("--delete-groups").split(",")
 				response = user.add_groups(groups=groups)
-				r3sponse.log(response)
+				Response.log(response)
 
 			# delete the user from groups.
 			elif self.arguments.present(['--delete-groups']):
 				groups = self.arguments.get("--delete-groups").split(",")
 				response = user.add_groups(groups=groups)
-				r3sponse.log(response)
+				Response.log(response)
 
 
 			# invalid.
@@ -110,7 +111,7 @@ class CLI(cl1.CLI):
 
 		# group.
 		elif self.arguments.present(['--group']):
-			syst3m.defaults.operating_system(supported=["linux"])
+			Defaults.operating_system(supported=["linux"])
 
 			# initialize a group object.
 			group = syst3m.Group(self.arguments.get("--group"))
@@ -118,24 +119,24 @@ class CLI(cl1.CLI):
 			# check if the group exists.
 			if self.arguments.present(['--check']):
 				response = group.check()
-				r3sponse.log(response)
+				Response.log(response)
 				if response.success: 
 					print("Group existance:",response["exists"])
 
 			# create a group.
 			elif self.arguments.present(['--create']):
 				response = group.create()
-				r3sponse.log(response)
+				Response.log(response)
 
 			# delete a group.
 			elif self.arguments.present(['--delete']):
 				response = group.delete()
-				r3sponse.log(response)
+				Response.log(response)
 
 			# list the current users.
 			elif self.arguments.present(['--list-users']):
 				response = group.list_users()
-				r3sponse.log(response)
+				Response.log(response)
 				if response.success: 
 					print(f"Users of group {group.name}:",response["users"])
 
@@ -143,19 +144,19 @@ class CLI(cl1.CLI):
 			elif self.arguments.present(['--add-users']):
 				users = self.arguments.get("--add-users").split(",")
 				response = group.add_users(users=users)
-				r3sponse.log(response)
+				Response.log(response)
 
 			# delete users from the group.
 			elif self.arguments.present(['--delete-users']):
 				users = self.arguments.get("--delete-users").split(",")
 				response = group.delete_users(users=users)
-				r3sponse.log(response)
+				Response.log(response)
 
 			# check if the specified users are enabled and remove all other users.
 			elif self.arguments.present(['--force-users']):
 				users = self.arguments.get("--force-users").split(",")
 				response = group.check_users(users=users)
-				r3sponse.log(response)
+				Response.log(response)
 
 
 			# invalid.
@@ -163,7 +164,7 @@ class CLI(cl1.CLI):
 
 		# free disk space.
 		elif self.arguments.present(["--disk-space"]):
-			syst3m.defaults.operating_system(supported=["linux"])
+			Defaults.operating_system(supported=["linux"])
 			import shutil
 			import math
 			def size(size_bytes):
@@ -190,7 +191,7 @@ class CLI(cl1.CLI):
 				print(f"Size {fp.path}: {size}")
 
 		# invalid.
-		else: self.invalid(json=syst3m.defaults.options.json)
+		else: self.invalid(json=Defaults.options.json)
 
 		#
 	def get_password(self, retrieve=False, check=False, message="Password:"):
@@ -204,7 +205,7 @@ class CLI(cl1.CLI):
 		return password
 # main.
 if __name__ == "__main__":
-	cli = CLI()
+	cli = CLI_()
 	if "--developer" in sys.argv:
 		cli.start()
 	else:
