@@ -200,7 +200,7 @@ class WebServer(objects.Thread):
 			try: del serialized[i]
 			except: a=1
 		serialized = f"{serialized}"
-		command = [Defaults.vars.executable, f"{SOURCE_PATH}classes/cache/fork.py", "--serialized", f"'{serialized}'", "--syst3m-webserver-tag", self.tag]
+		command = [str(Defaults.vars.executable), f"{SOURCE_PATH}classes/cache/fork.py", "--serialized", f"'{serialized}'", "--syst3m-webserver-tag", self.tag]
 		if self.log_level < 0:
 			command += [ "2>", "/dev/null"]
 		p = subprocess.Popen(command)
