@@ -15,7 +15,7 @@ def __prompt_password__(message="Password: "):
 	
 # init a default response.
 def __default_response__():
-	return r3sponse.ResponseObject({
+	return Response.ResponseObject({
 		"success":False,
 		"error":None,
 		"message":None,
@@ -225,14 +225,14 @@ def __execute_script__(
 	shell=False,
 	# pass a input string to the process.
 	input=None,
-	# set the executive program.
-	executive="sh",
+	# set the executable program.
+	executable="sh",
 ):
 	path = f"/tmp/shell_script.{__generate_pincode__(characters=32)}.sh"
 	__save_bytes__(path, script.encode())
 	__set_file_path_permission__(path,permission=755)
 	output = __execute__(
-		command=[executive, f"{path}"],
+		command=[executable, f"{path}"],
 		wait=wait,
 		timeout=timeout, 
 		return_format=return_format, 
